#!/bin/bash
#
# CentOS 5 = Qt 4.6.2 (from qt4-devel) or Qt 3.3.6 (from qt-devel)
# CentOS 6 = Qt 4.6.2 (from qt-devel)
#
echo "====="
set
echo "====="
# This exports into this script the DEB_{BUILD,HOST}_* and such
which dpkg-architecture && eval $(dpkg-architecture)
echo "====="
set
echo "====="
find / -xdev \( \
	-name "*QtWebKit*" \
	-or -name "stubs-*.h" \
	-or -name "c++config.h" \
	-or -name "stddef.h" \
	-or -name "stdarg.h" \
	\) -exec ls -lad {} \;
echo "====="
free || echo "no free"
df || echo "no df"
cat /proc/mounts || echo "no /proc/mounts"
echo "====="

if [ "X$(uname -i)" = "Xx86_64" ]
then
	if [ -d "/lib64" ]
	then
		LIB_SFX="64"
	fi
elif [ "X$(uname -i)" = "Xi386" ] || [ "X$(uname -i)" = "Xi486" ] || [ "X$(uname -i)" = "Xi586" ] || [ "X$(uname -i)" = "Xi686" ]
then
	if [ -d "/lib32" ]
	then
		LIB_SFX="32"
	fi
else
	LIB_SFX="-invalid"
fi
echo "LIB_SFX            = $LIB_SFX"

QT_QMAKE_EXE="qmake"
QT_VERSION_MAJOR=${QT_VERSION_MAJOR:="4"}	# default
if [ -x "/usr/bin/${QT_QMAKE_EXE}" ]
then
	QT_QMAKE_FULLPATH="/usr/bin/${QT_QMAKE_EXE}"
else
	# FIXME: Need to remove -executable
	list=$(find /usr/lib${LIB_SFX} -follow -type f -perm +0111 -name ${QT_QMAKE_EXE})
	if [ -x "/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}" ]
	then
		QT_QMAKE_FULLPATH="/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}"
	elif [ -x "/usr/lib/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}" ]
	then
		QT_QMAKE_FULLPATH="/usr/lib/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}"
	fi
fi

QT_VERSION=$("$QT_QMAKE_FULLPATH" -query QT_VERSION)
# if it was successful
if [ "X$QT_VERSION" != "X" ]
then
	QT_VERSION_MAJOR=$(echo "$QT_VERSION" | sed -e 's/^\([0-9]\)\..*/\1/')
fi
echo "QT_VERSION         = $QT_VERSION"
echo "QT_VERSION_MAJOR   = $QT_VERSION_MAJOR"


function do_diagnostic() {
	echo "===== $1 ====="
	find / -xdev \( \
		-name "qmake" -or \
		-name "${QT_QMAKE_EXE}" -or \
		-name "libQtCore.so.*" -or \
		-name "libQtWebKit.so.*" -or \
		-name "qglobal.h" -or \
		-name "plugins" -or \
		-name "phonon*" -or \
		-name "phonon_backend" -or \
		-name "libphonon.so.*" -or \
		-name "phonon_*.so*" -or \
		-name "libphonon_*.so*" \
		\) -exec ls -lad {} \;
	find / -xdev -type d \( \
		-name "plugins" -or \
		-name "phonon_backend" \
		\) -exec ls -la {} \;
	echo "===== $1 ====="
}

function do_error() {
	do_diagnostic "ERROR"
}

# I'm a bit confused which to use...
#
# On Linux 64bit:
#  DEB_BUILD_ARCH=amd64
#  DEB_BUILD_ARCH_CPU=amd64
#  DEB_BUILD_GNU_CPU=x86_64
#  DEB_BUILD_GNU_TYPE=x86_64-linux-gnu
#  DEB_BUILD_MULTIARCH=x86_64-linux-gnu
# On Linux 32bit:
#  DEB_BUILD_ARCH=i386
#  DEB_BUILD_ARCH_CPU=i386
#  DEB_BUILD_GNU_CPU=i686
#  DEB_BUILD_GNU_TYPE=i686-linux-gnu
#  DEB_BUILD_MULTIARCH=i386-linux-gnu
#
# So we resolve this matter below...
[ -n "$DEB_BUILD_GNU_CPU" ] && UNAME_MACH_HW=${UNAME_MACH_HW:=$DEB_BUILD_GNU_CPU}
#[ -n "$DEB_BUILD_ARCH_CPU" ] && UNAME_MACH_HW=${UNAME_MACH_HW:=$DEB_BUILD_ARCH_CPU}
[ -n "RPM_ARCH" ] && UNAME_MACH_HW=${RPM_ARCH}
[ "x$UNAME_MACH_HW" = "x" ] && UNAME_MACH_HW=$(uname -p)
if [ "x$UNAME_MACH_HW" = "x" ]
then
	echo "ERROR: Unable to determine build / userspace CPU type" 1>&2
	echo "UNAME_MACH_HW -a = " $(uname -a)
	do_error
	exit 1
fi

echo "UNAME_MACH_HW      = $UNAME_MACH_HW"
[ -n "$DEB_BUILD_GNU_TYPE" ] && GCC_ARCH=${GCC_ARCH:=$DEB_BUILD_GNU_TYPE}
[ -n "$GCC_ARCH" ] && GCC_ARCH=${GCC_ARCH:="invalid-${DEB_BUILD_GNU_SYSTEM}"}

[ -n "$DEB_BUILD_MULTIARCH" ] && GCC_ARCH2="${GCC_ARCH2:=$DEB_BUILD_MULTIARCH}"
[ -n "$GCC_ARCH2" ] && GCC_ARCH2=${GCC_ARCH2:="invalid-${DEB_BUILD_GNU_SYSTEM}"}

echo "uname -a           = $(uname -a)"
echo "uname -i           = $(uname -i)"
echo "uname -p           = $(uname -p)"
echo "uname -m           = $(uname -m)"

GCC_LABEL=$(gcc -dumpmachine)
[ -z "$GCC_LABEL" ] && GCC_LABEL=$MACHTYPE
#if echo "$GCC_LABEL" | grep -q "\-redhat\-"
#then
#	GCC_LABEL="$(uname -i)-"
#fi
echo "GCC_LABEL          = $GCC_LABEL"

[ -z "$MACHTYPE" ] && MACHTYPE="invalid"
[ -z "$GCC_ARCH" ] && GCC_ARCH="invalid"
[ -z "$GCC_ARCH2" ] && GCC_ARCH2="invalid"
[ "x$GCC_ARCH" = "x$GCC_ARCH2" ] && [ "$GCC_ARCH" != "invalid" ] && GCC_ARCH2="invalid-${DEB_BUILD_GNU_SYSTEM}"

GCC_VERSION=$(gcc -v 2>&1 | grep "gcc version " | sed -e 's/^gcc version \([0-9\.]*\).*/\1/')
GCC_VERSION_MAJMIN=$(echo "$GCC_VERSION" | sed -e 's#^\([0-9]*\.[0-9]*\).*#\1#')

echo "MACHTYPE           = $MACHTYPE"
echo "GCC_ARCH           = $GCC_ARCH"
echo "GCC_ARCH2          = $GCC_ARCH2"
echo "GCC_VERSION        = $GCC_VERSION"
echo "GCC_VERSION_MAJMIN = $GCC_VERSION_MAJMIN"


if [ -f "build.properties.orig" ]
then
	# restore original
	cp -v -f "build.properties.orig" "build.properties"
else
	# backup
	cp -v "build.properties" "build.properties.orig"
fi


echo "=== build.properties ==="
#qtjambi.java.library.path       = /usr/lib/gcc/i686-pc-linux-gnu/4.5.2
# /usr/lib/jni
sed -e "s#^\#\?\(qtjambi\.java\.library\.path.*=\)\(.*\)\$#\\#\\1\\2#" -i "build.properties"

if [ "x$MY_RPM_JAVAJNIDIR" != "x" ]
then
	echo "Setting: qtjambi.java.library.path = $MY_RPM_JAVAJNIDIR"
	echo "qtjambi.java.library.path = $MY_RPM_JAVAJNIDIR" >> "build.properties"
fi

# /usr/lib64/qt4/bin/qmake
# /usr/bin/qmake
for try in \
	"/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}" \
	"/usr/lib/qt${QT_VERSION_MAJOR}/bin/${QT_QMAKE_EXE}" \
	"/usr/bin/${QT_QMAKE_EXE}" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: ${QT_QMAKE_EXE}" 1>&2
		do_error
		exit 1
	fi

	#qtjambi.qt.qmake                        = qmake
	#qtjambi.qt.bindir                       = /usr/bin
	if [ -x "$try" ]
	then
		tmp_1=$(dirname "${try}")
		echo "Setting: qtjambi.qt.qmake = ${QT_QMAKE_EXE} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.qt\.qmake.*=\)\(.*\)\$#\\1${QT_QMAKE_EXE}#" -i "build.properties"
		echo "Setting: qtjambi.qt.bindir = ${tmp_1} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.qt\.bindir.*=\)\(.*\)\$#\\1${tmp_1}#" -i "build.properties"
		break
	fi
done


# /usr/lib/x86_64-linux-gnu/libQtCore.so.4
# /usr/lib/libQtCore.so.4 (never seen but possible)
for try in \
	"/usr/lib${LIB_SFX}/${GCC_ARCH}/libQtCore.so.${QT_VERSION_MAJOR}" \
	"/usr/lib${LIB_SFX}/${GCC_ARCH2}/libQtCore.so.${QT_VERSION_MAJOR}" \
	"/usr/lib${LIB_SFX}/libQtCore.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/${GCC_ARCH}/libQtCore.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/${GCC_ARCH2}/libQtCore.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/libQtCore.so.${QT_VERSION_MAJOR}" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: libQtCore.so.${QT_VERSION_MAJOR}" 1>&2
		do_error
		exit 1
	fi

	#qtjambi.qt.libdir                       = /usr/lib/qt4
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		echo "Setting: qtjambi.qt.libdir = ${tmp_1} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.qt\.libdir.*=\)\(.*\)\$#\\1${tmp_1}#" -i "build.properties"
		break
	fi
done


for try in \
	"/usr/include/qt${QT_VERSION_MAJOR}/Qt/qglobal.h" \
	"/usr/include/Qt/qglobal.h" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: Qt/qglobal.h" 1>&2
		do_error
		exit 1
	fi

	#qtjambi.qt.includedir                   = /usr/include/qt4 
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		tmp_2=$(dirname "${tmp_1}")
		echo "Setting: qtjambi.qt.includedir = ${tmp_2} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.qt\.includedir.*=\)\(.*\)\$#\\1${tmp_2}#" -i "build.properties"
		break
	fi
done

for try in \
	"/usr/lib${LIB_SFX}/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins" \
	"/usr/lib${LIB_SFX}/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins" \
	"/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/plugins" \
	"/usr/lib/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins" \
	"/usr/lib/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins" \
	"/usr/lib/qt${QT_VERSION_MAJOR}/plugins" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: plugins" 1>&2
		do_error
		exit 1
	fi

	#qtjambi.qt.pluginsdir                   = /usr/lib/qt4/plugins
	if [ -d "$try" ]
	then
		#tmp_1=$(dirname "${try}")	# we include plugins last path part now
		echo "Setting: qtjambi.qt.pluginsdir = ${try} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.qt\.pluginsdir.*=\)\(.*\)\$#\\1${try}#" -i "build.properties"
		break
	fi
done

# Added to let it autodetect, but found issue was use of /plugins/ in configured path now.
if false
then
	# Let it autodetect
	echo "Comment out: qtjambi.phonon.kdephonon"
	sed -e "s#^\#\?\(qtjambi\.phonon\.kdephonon.*=\)\(.*\)\$#\#\\1\\2#" -i "build.properties"
fi

# /usr/include/qt4/phonon/phonon
# /usr/include/phonon/phonon
for try in \
	"/usr/include/qt${QT_VERSION_MAJOR}/phonon/phonon" \
	"/usr/include/phonon/phonon" \
	"/usr/include/phonon/phonondefs.h" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: phonon/phonon" 1>&2
		do_error
		exit 1
	fi

	#qtjambi.phonon.includedir       = /usr/include
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		tmp_2=$(dirname "${tmp_1}")
		echo "Setting: qtjambi.phonon.includedir = ${tmp_2} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.phonon\.includedir.*=\)\(.*\)\$#\\1${tmp_2}#" -i "build.properties"
		break
	fi
done

# /usr/lib/x86_64-linux-gnu/libphonon.so.4 (never seen but possible)
# /usr/lib/libphonon.so.4
for try in \
	"/usr/lib${LIB_SFX}/${GCC_ARCH}/libphonon.so.${QT_VERSION_MAJOR}" \
	"/usr/lib${LIB_SFX}/${GCC_ARCH2}/libphonon.so.${QT_VERSION_MAJOR}" \
	"/usr/lib${LIB_SFX}/libphonon.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/${GCC_ARCH}/libphonon.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/${GCC_ARCH2}/libphonon.so.${QT_VERSION_MAJOR}" \
	"/usr/lib/libphonon.so.${QT_VERSION_MAJOR}" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: libphonon.so.${QT_VERSION_MAJOR}" 1>&2
		do_diagnostic "INFO"
		# Try for qtjambi.phonon.kdephonon=true before disabling phonon
		break
	fi

	#qtjambi.phonon.libdir           = /usr/lib
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		echo "Setting: qtjambi.phonon.libdir = ${tmp_1} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.phonon\.libdir.*=\)\(.*\)\$#\\1${tmp_1}#" -i "build.properties"
		break
	fi
done

disable_phonon=0
for try in \
	"/usr/lib${LIB_SFX}/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib${LIB_SFX}/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib${LIB_SFX}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib${LIB_SFX}/kde4/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib/plugins/phonon_backend/libphonon_gstreamer.so" \
	"/usr/lib/kde4/plugins/phonon_backend/libphonon_gstreamer.so" \
	"FAIL"
do
	if [ "$try" = "FAIL" ]
	then
		echo "$0: Unable to find: phonon_backend/libphonon_gstreamer.so or phonon_backend/phonon_gstreamer.so" 1>&2
		#do_diagnostic "INFO"
		# Disable it all
		disable_phonon=1
		break
	fi

	#qtjambi.phonon.pluginsdir       = /usr/lib/qt4/plugins
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		tmp_2=$(dirname "${tmp_1}")
		#tmp_3=$(dirname "${tmp_2}")	# we include plugins last path part now
		echo "Setting: qtjambi.phonon.pluginsdir = ${tmp_2} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.phonon\.pluginsdir.*=\)\(.*\)\$#\\1${tmp_2}#" -i "build.properties"
		# When setting it "true" this removes the "lib" prefix for "phonon_backend/libphonon_gstreamer.so"
		if echo "${try}" | grep -q "libphonon_gstreamer"
		then
			#qtjambi.phonon.kdephonon        = false
			sed -e "s#^\#\?\(qtjambi\.phonon\.kdephonon.*=\)\(.*\)\$#\\1false#" -i "build.properties"
		else
			#qtjambi.phonon.kdephonon        = true
			sed -e "s#^\#\?\(qtjambi\.phonon\.kdephonon.*=\)\(.*\)\$#\\1true#" -i "build.properties"
		fi
		break
	fi
done


# Try for KDE phonon  (libphonon_gstreamer.so)
if [ $disable_phonon -gt 0 ]
then
	disable_phonon=0
	# /usr/lib/x86_64-linux-gnu/qt4/plugins/phonon_backend/phonon_gstreamer.so (never seen but possible)
	# /usr/lib/qt4/plugins/phonon_backend/phonon_gstreamer.so
	# /usr/lib/plugins/phonon_backend/phonon_gstreamer.so (never seen but possible)
	for try in \
		"/usr/lib${LIB_SFX}/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib${LIB_SFX}/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib${LIB_SFX}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib${LIB_SFX}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib${LIB_SFX}/kde4/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib/${GCC_ARCH}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib/${GCC_ARCH2}/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib/qt${QT_VERSION_MAJOR}/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib/plugins/phonon_backend/phonon_gstreamer.so" \
		"/usr/lib/kde4/plugins/phonon_backend/phonon_gstreamer.so" \
		"FAIL"
	do
		if [ "$try" = "FAIL" ]
		then
			echo "$0: Unable to find: phonon_backend/phonon_gstreamer.so" 1>&2
			#do_diagnostic "INFO"
			# Disable it all (well after we try for KDE phonon)
			disable_phonon=1
			break
		fi

	#qtjambi.phonon.pluginsdir       = /usr/lib/qt4/plugins
	if [ -f "$try" ]
	then
		tmp_1=$(dirname "${try}")
		tmp_2=$(dirname "${tmp_1}")
		#tmp_3=$(dirname "${tmp_2}")
		echo "Setting: qtjambi.phonon.pluginsdir = ${tmp_2} (found: ${try})"
		sed -e "s#^\#\?\(qtjambi\.phonon\.pluginsdir.*=\)\(.*\)\$#\\1${tmp_2}#" -i "build.properties"
		# When setting it "true" this removes the "lib" prefix for "phonon_backend/libphonon_gstreamer.so"
		#qtjambi.phonon.kdephonon        = false
		sed -e "s#^\#\?\(qtjambi\.phonon\.kdephonon.*=\)\(.*\)\$#\\1true#" -i "build.properties"
		break
	fi
done
fi

if [ $disable_phonon -gt 0 ]
then
	echo "Disabling all phonon support..."
	sed -e "s#^\#\?\(qtjambi\.phonon\..*=\)\(.*\)\$#\\#\\1\\2#" -i "build.properties"
	echo "" >> "build.properties"
	echo "qtjambi.phonon = false" >> "build.properties"
fi

#sed -n -i -e "s#^\#\?\(generator\\.includepaths\).*#\\#\1#" "build.properties"
#generator.includepaths         = ${basedir}/generator/targets:${basedir}/src/cpp:${java.home.target}/include:${java.home.target}/include/${java.osarch.target}:/usr/include:/usr/include/c++/4.4.4:/usr/include/c++/4.4.4/x86_64-redhat-linux:/usr/lib/gcc/x86_64-redhat-linux/4.4.4/include
#
# generator.includepaths          = ${basedir}/generator/targets:${basedir}/src/cpp:${java.home.target}/include:${java.home.target}/include/${java.osarch.target}

# /usr/include:
#/usr/include/c++/4.4.4:
#/usr/include/c++/4.4.4/x86_64-redhat-linux:
#/usr/lib/gcc/x86_64-redhat-linux/4.4.4/include

# GCC_LABEL
#/usr/include/c++/4.5/x86_64-suse-linux/
#/usr/lib64/gcc/x86_64-suse-linux/4.5/

GENERATOR_INCLUDEPATHS='${basedir}/generator/targets:${basedir}/src/cpp:${java.home.target}/include:${java.home.target}/include/${java.osarch.target}'
for try in \
	"/usr/include" \
	"/usr/include/${GCC_ARCH}" \
	"/usr/include/${GCC_ARCH2}" \
	"/usr/include/c++/${GCC_VERSION}" \
	"/usr/include/c++/${GCC_VERSION_MAJMIN}" \
	"/usr/include/c++/${GCC_VERSION}/${GCC_LABEL}" \
	"/usr/include/c++/${GCC_VERSION}/${GCC_ARCH}" \
	"/usr/include/c++/${GCC_VERSION}/${GCC_ARCH2}" \
	"/usr/include/c++/${GCC_VERSION_MAJMIN}/${GCC_LABEL}" \
	"/usr/include/c++/${GCC_VERSION_MAJMIN}/${GCC_ARCH}" \
	"/usr/include/c++/${GCC_VERSION_MAJMIN}/${GCC_ARCH2}" \
	"/usr/lib${LIB_SFX}/gcc/${GCC_LABEL}/${GCC_VERSION}/include" \
	"/usr/lib/gcc/${GCC_ARCH}/${GCC_VERSION}/include" \
	"/usr/lib/gcc/${GCC_ARCH2}/${GCC_VERSION}/include" \
	"/usr/lib${LIB_SFX}/gcc/${GCC_LABEL}/${GCC_VERSION_MAJMIN}/include" \
	"/usr/lib/gcc/${GCC_ARCH}/${GCC_VERSION_MAJMIN}/include" \
	"/usr/lib/gcc/${GCC_ARCH2}/${GCC_VERSION_MAJMIN}/include" \
	"DONE"
do
	if [ -d "$try" ]
	then
		echo "Adding generator.includepaths directory: ${try}"
		GENERATOR_INCLUDEPATHS="${GENERATOR_INCLUDEPATHS}:${try}"
	fi
done
echo "Setting: generator.includepaths = ${GENERATOR_INCLUDEPATHS}"
sed -e "s#^\#\?\(generator\.includepaths.*=\)\(.*\)\$#\\#\\1\\2#" -i "build.properties"
echo "generator.includepaths = ${GENERATOR_INCLUDEPATHS}" >> "build.properties"

# qtjambi.configuration
sed -e "s#^\#\?qtjambi\.configuration[ \t].*=.*\$#\\#\\0#" -i "build.properties"
echo | tee -a "build.properties"
echo "qtjambi.configuration = release" | tee -a "build.properties"


if [ -f "version.properties.template.orig" ]
then
	# restore original
	cp -v -f "version.properties.template.orig" "version.properties.template"
else
	# backup
	cp -v "version.properties.template" "version.properties.template.orig"
fi

if [ -f "version.properties.template" ]
then
	if [ "x$MY_RPM_JAVAJNIDIR" != "x" ]
	then
		echo "=== version.properties.template ==="
		echo "qtjambi.jni.libdir.1 = $MY_RPM_JAVAJNIDIR" | tee -a "version.properties.template"
	fi
fi


antcontrib_set=0
if [ -f "antcontrib.properties" ]
then
	echo "antcontrib.properties"
	sed -e "s#^\(antcontrib\.download\.url\)\(.*\)\$#\\#\\1\\2#" -i "antcontrib.properties"
	# OpenSuSE
	if [ -e "/usr/share/java/ant-contrib.jar" ]
	then
		sed -e "s#^\(antcontrib\.system\.location\)\(.*\)\$#\\#\\1\\2#" -i "antcontrib.properties"
		echo "antcontrib.system.location = /usr/share/java/ant-contrib.jar"
		echo "antcontrib.system.location = /usr/share/java/ant-contrib.jar" >> antcontrib.properties
		antcontrib_set=1
	fi
	# Fedora (RHEL/CentOS)
	if [ -e "/usr/share/java/ant/ant-contrib.jar" ]
	then
		sed -e "s#^\(antcontrib\.system\.location\)\(.*\)\$#\\#\\1\\2#" -i "antcontrib.properties"
		echo "antcontrib.system.location = /usr/share/java/ant/ant-contrib.jar"
		echo "antcontrib.system.location = /usr/share/java/ant/ant-contrib.jar" >> antcontrib.properties
		antcontrib_set=1
	fi

	# wget http://downloads.sourceforge.net/project/ant-contrib/ant-contrib/1.0b3/ant-contrib-1.0b3-bin.zip
	if [ $antcontrib_set -eq 0 ] && [ -f "${RPM_SOURCE_DIR}/ant-contrib-1.0b3-bin.zip" ]
	then
		antcontrib_path="${RPM_SOURCE_DIR}/ant-contrib-1.0b3-bin.zip"
		echo "Setting antcontrib.download.url to local file URL file://${antcontrib_path}"
		#antcontrib.system.location = /usr/share/ant-contrib/lib/ant-contrib.jar
		#antcontrib.download.url = http://downloads.sourceforge.net/project/ant-contrib/ant-contrib/1.0b3/ant-contrib-1.0b3-bin.zip
		sed -e "s#^\(antcontrib\.system\.location\)\(.*\)\$#\\#\\1\\2#" -i "antcontrib.properties"
		echo "antcontrib.download.url = file://${antcontrib_path}" >> antcontrib.properties
		antcontrib_set=1
	fi	
fi

if [ -f "tests.properties" ]
then
	echo "tests.properties"
	sed -e "s#^\(tests\.junit\)\(.*\)\$#\\#\\1\\2#" -i "tests.properties"
	sed -e "s#^\(tests\.hamcrest\)\(.*\)\$#\\#\\1\\2#" -i "tests.properties"
	if [ -e "/usr/share/java/junit4.jar" ]
	then
		echo "tests.junit = /usr/share/java/junit4.jar"
		echo "tests.junit = /usr/share/java/junit4.jar" >> tests.properties
	fi
	if [ -e "/usr/share/java/hamcrest.jar" ]
	then
		echo "tests.hamcrest = /usr/share/java/hamcrest.jar"
		echo "tests.hamcrest = /usr/share/java/hamcrest.jar" >> tests.properties
	fi
fi


# overwrite with the system one from /usr/share/java/jogl.jar
if [ -f "jars/jogl.jar" ] && [ -f "/usr/share/java/jogl.jar" ]
then
	cp -v -f "/usr/share/java/jogl.jar" "jars/jogl.jar"
fi

echo
echo
echo "===vvv=== antcontrib.properties ===vvv==="
cat antcontrib.properties
echo "===^^^=== antcontrib.properties ===^^^==="
echo
echo
echo "===vvv=== build.properties ===vvv==="
cat build.properties
echo "===^^^=== build.properties ===^^^==="
echo
echo
if [ -f "buildpath.properties" ]
then
	echo "===vvv=== buildpath.properties ===vvv==="
	cat buildpath.properties
	echo "===^^^=== buildpath.properties ===^^^==="
	echo
fi
echo
echo "===vvv=== tests.properties ===vvv==="
cat tests.properties
echo "===^^^=== tests.properties ===^^^==="
echo
echo
if [ -f "version.properties" ]
then
	echo "===vvv=== version.properties ===vvv==="
	cat version.properties
	echo "===^^^=== version.properties ===^^^==="
	echo
	echo
fi
if [ -f "version.properties.template" ]
then
	echo "===vvv=== version.properties.template ===vvv==="
	cat version.properties.template
	echo "===^^^=== version.properties.template ===^^^==="
	echo
	echo
fi

# Debugging
exit 0
