#!/bin/bash
#
#  This script is mainly tested on Fedora but feedback
#
#  Maintained by Darryl L. Miles <darryl.miles@darrylmiles.org>
#
LIB_SFX=""
if [ "X$(uname -m)" = "Xx86_64" ]
then
	if [ -d "/usr/lib64" ]
	then
		LIB_SFX="64"
	fi
else
	# The default is correct for most 32bit systems LIB_SFX=""
	if [ -d "/usr/lib32" ]
	then
		LIB_SFX="32"
	fi
fi

# Location of *.so
if [ -z "$qtjambi_javajnidir" ]
then
	if [ -d "/usr/lib${LIB_SFX}/qtjambi" ]
	then
		qtjambi_javajnidir="/usr/lib${LIB_SFX}/qtjambi"
	elif [ -d "/usr/lib${LIB_SFX}/jni" ]
	then
		qtjambi_javajnidir="/usr/lib${LIB_SFX}/jni"
	fi
fi

# Location of qtjambi.jar
if [ -z "$qtjambidir" ]
then
	if [ -d "/usr/lib${LIB_SFX}/java" ] && [ -f "/usr/lib${LIB_SFX}/java/qtjambi.jar" ]
	then
		qtjambidir="/usr/lib${LIB_SFX}/java"
	elif [ -f "/usr/share/java/qtjambi.jar" ]
	then
		qtjambidir="/usr/share/java"
	fi
fi

# Location of qtjambi-designer.jar
if [ -z "$qtjambi_javadir" ]
then
	if [ -f "/usr/share/java/qtjambi-designer.jar" ]
	then
		qtjambi_javadir="/usr/share/java"
	fi
fi

if [ -z "$qt_designer_exec" ]
then
	if [ -x "/usr/lib${LIB_SFX}/qt4/bin/designer" ]
	then
		qt_designer_exec="/usr/lib${LIB_SFX}/qt4/bin/designer"
	elif [ -x "/usr/bin/designer-qt4" ]
	then
		qt_designer_exec="/usr/bin/designer-qt4"
	elif [ -x "/usr/bin/designer" ]
	then
		qt_designer_exec="/usr/bin/designer"
	fi
fi

# BEFORE
echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"
echo "CLASSPATH=$CLASSPATH"
echo "QT_PLUGIN_PATH=$QT_PLUGIN_PATH" 
echo "JAVA_HOME=$JAVA_HOME"

if [ -z "$qtjambidir" ]
then
	# This is the location of qtjambi.jar and such...
	# Try the command: find / -name "qtjambi.jar"
	# to attempt to locate.
	echo "$0: Unable to resolve qtjambidir (the directory location of the QtJambi Java libraries)" 1>&2
	exit 1
fi

if [ -z "$qtjambi_javadir" ]
then
	# This is the location of qtjambi.jar and such...
	# Try the command: find / -name "qtjambi-designer.jar"
	# to attempt to locate.
	echo "$0: Unable to resolve qtjambi_javadir (the directory location of the QtJambi Designer Java libraries)" 1>&2
	exit 1
fi

if [ -z "$qtjambi_javajnidir" ]
then
	# This is the location of libqtjambi.so and such...
	# Try the command: find / -name "libqtjambi.so"
	# to attempt to locate.
	echo "$0: Unable to resolve qtjambi_javajnidir (the directory location of the QtJambi JNI libraries)" 1>&2
	exit 1
fi

if [ -z "$qt_designer_exec" ]
then
	echo "$0: Unable to resolve qt_designer_exec (the file location of the Qt Designer binary)" 1>&2
	exit 1
fi

if [ -n "$LD_LIBRARY_PATH" ]
then
	if echo "$LD_LIBRARY_PATH" | grep -q -- "$qtjambi_javajnidir"
	then
		# noop
		true
	else
		LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$qtjambi_javajnidir"
		export LD_LIBRARY_PATH
	fi
else
	LD_LIBRARY_PATH="$qtjambi_javajnidir"
	export LD_LIBRARY_PATH
fi

# Ubuntu has /usr/lib/x86_64-linux-gnu/libQtCore.so.4 that is not
#  part of the ld.so.conf system resolution
if [ -f "/usr/lib/$(uname -m)-linux-gnu/libQtCore.so.4" ]
then
	LD_LIBRARY_PATH="$LD_LIBRARY_PATH:/usr/lib/$(uname -m)-linux-gnu"
	export LD_LIBRARY_PATH
fi
# Remove leading ":" for empty entry
LD_LIBRARY_PATH=$(echo "$LD_LIBRARY_PATH" | sed -e 's/^://')

if [ ! -f "${qtjambi_javadir}/qtjambi-examples.jar" ]
then
	echo "$0: WARNING: You do not have qtjambi-examples.jar installed" 2>&1
fi

if [ -n "$CLASSPATH" ]
then
	if echo "$CLASSPATH" | grep -q -- "$qtjambi_javadir"
	then
		# noop
		true
	else
		# build-classpath qtjambi-designer qtjambi qtjambi-examples
		CLASSPATH="$CLASSPATH:${qtjambi_javadir}/qtjambi-designer.jar:${qtjambidir}/qtjambi.jar:${qtjambi_javadir}/qtjambi-examples.jar"
		export CLASSPATH
	fi
else
	# build-classpath qtjambi-designer qtjambi qtjambi-examples
	CLASSPATH="${qtjambi_javadir}/qtjambi-designer.jar:${qtjambidir}/qtjambi.jar:${qtjambi_javadir}/qtjambi-examples.jar"
	export CLASSPATH
fi
# Remove leading ":" for empty entry
CLASSPATH=$(echo "$CLASSPATH" | sed -e 's/^://')

if [ -d "${qtjambi_javajnidir}/qtjambi/plugins" ]
then
	# at least Ubuntu 11.10+
	if echo "$QT_PLUGIN_PATH" | grep -q -- "${qtjambi_javajnidir}/qtjambi/plugins"
	then
		# noop
		true
	else
		QT_PLUGIN_PATH="$QT_PLUGIN_PATH:${qtjambi_javajnidir}/qtjambi/plugins"
		export QT_PLUGIN_PATH
	fi
elif [ -d "${qtjambi_javajnidir}/plugins" ]
then
	# at least Fedora15+
	if echo "$QT_PLUGIN_PATH" | grep -q -- "${qtjambi_javajnidir}/plugins"
	then
		# noop
		true
	else
		QT_PLUGIN_PATH="$QT_PLUGIN_PATH:${qtjambi_javajnidir}/plugins"
		export QT_PLUGIN_PATH
	fi
fi
# Remove leading ":" for empty entry
QT_PLUGIN_PATH=$(echo "$QT_PLUGIN_PATH" | sed -e 's/^://')


if [ -z "$JAVA_HOME" ]
then
	# at least Fedora15+
	if [ -d "/usr/lib/jvm/java" ]
	then
		JAVA_HOME="/usr/lib/jvm/java"
		export JAVA_HOME
	elif [ -d "/usr/lib/jvm/default-java" ]
	then
		# at least Ubuntu 11.10+
		JAVA_HOME="/usr/lib/jvm/default-java"
		export JAVA_HOME
	fi

	if [ -z "$JAVA_HOME" ]
	then
		echo "$0: unable to resolve JAVA_HOME, please manually setup: export JAVA_HOME=\"/some/directory\"" 1>&2
		exit 1
	fi
fi


# AFTER
echo "qtjambi_javajnidir=$qtjambi_javajnidir"
echo "qtjambi_javadir=$qtjambi_javadir"
echo "qtjambidir=$qtjambidir"
echo "qt_designer_exec=$qt_designer_exec"
echo "LD_LIBRARY_PATH=$LD_LIBRARY_PATH"
echo "CLASSPATH=$CLASSPATH"
echo "QT_PLUGIN_PATH=$QT_PLUGIN_PATH"
echo "JAVA_HOME=$JAVA_HOME"

echo "exec" "$qt_designer_exec" $*
exec "$qt_designer_exec" $*
